@@ -1,12 +1,14 @@
 """
 This module handles reading from and writing to a FAT32 filesystem.
 """
+import calendar
 import datetime
 import struct
 import sys
 
 
-from collections import namedtuple
+from .utils import slicer
+
 
 # TODO: read https://stackoverflow.com/questions/13775893/converting-struct-to-byte-and-back-to-struct
 #       and research a bit into this being a reasonable way to convert bytes
@@ -27,7 +29,7 @@ ATTRIBUTES = {
 # TODO: this is actually a hack right now, and there might be a simpler way to
 #       do it
 ALL_ASCII = b"".maketrans(b"", b"")  # a bit hacky, but works
-FILENAME_CHARS = b"0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ!#$%&'()-@^_`{}~\xe5"
+FILENAME_CHARS = b"0123456789 ABCDEFGHIJKLMNOPQRSTUVWXYZ!#$%&'()-@^_`{}~\xe5"
 REMAIN_ASCII = ALL_ASCII
 for idx, char in enumerate(FILENAME_CHARS):
     char = FILENAME_CHARS[idx:idx + 1]
@@ -80,9 +82,10 @@ def read_time(bytes_, mili=0):
     # we know theres an issue in some Linux based systems that make
     # 0xffffffff datetimes for some FileRecords (that don't seem to belong to
     # the files, some kind of temporary record) so we must check a few things:
-    year   = max(1980,  min(2107, year))  # clips the values to within range
-    month  = max(1,     min(12,  month))
-    day    = max(1,     day)
+    year   = max(1980,  min(2107,    year))  # clips the values to within range
+    month  = max(1,     min(12,     month))
+    _weeks, max_days = calendar.monthrange(year, month)
+    day    = max(1,     min(max_days, day))
     hour   = min(23,   hour)
     minute = min(59, minute)
     second = min(59, second)
@@ -398,7 +401,7 @@ class FileRecord:
                f"    {'created':12}: {self.created}\n" 
                f"    {'last_access':12}: {self.last_access}\n" 
                f"    {'modified':12}: {self.modified}\n" 
-               f"    {'deleted':12}:{self.deleted:>12}\n" 
+               f"    {'deleted':12}:{str(self.deleted):>12}\n" 
                f">"
         )
     
@@ -478,16 +481,6 @@ class Directory:
         skipped since we don't want to tread into Microsoft patents territory.
         Might think of supporting Linux-stlye LFNs.
         """
-
-        def slicer(iterable):
-            """
-            Slices a bytes/bytearray object into 32-byte sized chunks for easier
-            parsing.
-            """
-            full_length = len(iterable)
-            part_length = (full_length // 32)
-            for i in range(part_length):
-                yield iterable[i * 32: i * 32 + 32]
         
         def lfn_filter(record):
             """
@@ -517,7 +510,7 @@ class Directory:
             lfn_filter,
             (
                 FileRecord(s)
-                for s in slicer(raw_data) 
+                for s in slicer(raw_data, 32)
                 if s != bytes(32)
             )
         ))
